@@ -6,6 +6,7 @@ use CGI qw(header);
 use Config qw(%Config config_sh);
 use Net::Domain qw(hostname);
 use Carp (); 
+use Data::Dumper;
 use Module::CoreList;
 use File::Find;
 use File::Spec;
@@ -23,26 +24,26 @@ require HTML::Perlinfo::Apache;
 require HTML::Perlinfo::Modules;
 require HTML::Perlinfo::License;
 
-@HTML::Perlinfo::ISA    = qw(Exporter);
-@HTML::Perlinfo::EXPORT = qw(perlinfo);
+our @ISA    = qw(Exporter);
+our @EXPORT = qw(perlinfo);
 
-$VERSION = '1.00';
+$VERSION = '1.05';
 
 # This is for modperl
 initialize_globals();
 
-  sub perl_print_info {
+  sub print_perl_info {
 
 	  $flag = $_[0];
-	  my $HTML = perl_info_print_htmlhead();
-	  $HTML .= perl_info_print_script()  if ($flag eq "INFO_ALL");
-	  $HTML .= perl_info_print_credits() if ($flag eq "INFO_CREDITS");
-	  $HTML .= perl_info_print_config() if ($flag eq "INFO_CONFIG");
-	  $HTML .= perl_info_print_httpd() if ($flag eq "INFO_APACHE");
-	  $HTML .= perl_info_print_general() if ($flag eq "INFO_ALL" || $flag eq "INFO_GENERAL");
-	  $HTML .= perl_info_print_variables() if  ($flag eq "INFO_ALL" || $flag eq "INFO_VARIABLES");
-          $HTML .= perl_info_print_modules()   if  ($flag eq "INFO_ALL" || $flag eq "INFO_MODULES");
-          $HTML .= perl_info_print_license()   if  ($flag eq  "INFO_ALL" || $flag eq "INFO_LICENSE");
+	  my $HTML = print_htmlhead();
+	  $HTML .= print_script()    if  ($flag eq "INFO_ALL");
+	  $HTML .= print_credits()   if  ($flag eq "INFO_CREDITS");
+	  $HTML .= print_config()    if  ($flag eq "INFO_CONFIG");
+	  $HTML .= print_httpd()     if  ($flag eq "INFO_APACHE");
+	  $HTML .= print_general()   if  ($flag eq "INFO_ALL"  || $flag eq "INFO_GENERAL");
+	  $HTML .= print_variables() if  ($flag eq "INFO_ALL"  || $flag eq "INFO_VARIABLES");
+          $HTML .= print_modules()   if  ($flag eq "INFO_ALL"  || $flag eq "INFO_MODULES");
+          $HTML .= print_license()   if  ($flag eq "INFO_ALL"  || $flag eq "INFO_LICENSE");
 	  $HTML .= "</div></body></html>";
 	  return $HTML;
   }
@@ -51,12 +52,13 @@ initialize_globals();
 
   sub perlinfo { 
 
-	  my $INFO = $_[0] =~ /^\s*$/ ? "INFO_ALL" : $_[0];
+          my $info = shift;
+	  $info = 'INFO_ALL' unless defined $info;
 	  Carp::croak "@_ is an invalid perlinfo() parameter"
-	  if (($INFO !~ /INFO_ALL|INFO_GENERAL|INFO_CREDITS|INFO_CONFIG|INFO_VARIABLES|INFO_APACHE|INFO_MODULES|INFO_LICENSE/) || @_ > 1); 
+	  if (($info !~ /INFO_ALL|INFO_GENERAL|INFO_CREDITS|INFO_CONFIG|INFO_VARIABLES|INFO_APACHE|INFO_MODULES|INFO_LICENSE/) || @_ > 1); 
 	  # Andale!  Andale!  Yee-Hah! 
 	  my $HTML = defined($ENV{'SERVER_SOFTWARE'}) ? header : '';
-	  $HTML .= perl_print_info($INFO);
+	  $HTML .= print_perl_info($info);
 	  defined wantarray ? return $HTML : print $HTML;
   }
 1;
@@ -121,12 +123,23 @@ Shows all of the above. This is the default value.
 
 =back
 
+=head1 CUSTOMIZING THE HTML
+
+The simpliest way to alter the HTML is to assign it to a scalar. For example:
+
+       my $example = perlinfo();    # Now I can do whatever I want with $example
+       $example =~ s/Perl/Java/ig;  # Make everyone laugh  
+       print $example;       
+
+HTML::Perlinfo also provides object methods which make altering some HTML elements less helter skelter.  
+
 =head1 OBJECT METHODS
 
 These object methods allow you to change the HTML CSS settings to achieve a stylish effect. When using them, you must pass them a parameter. Please see your favorite HTML guide for acceptable CSS values. Refer to the HTML source code of perlinfo for the defaults.
 
 Method name/Corresponding CSS element
 
+ title                  / page title (only non-CSS element)
  bg_image 		/ background_image
  bg_position 		/ background_position
  bg_repeat 		/ background_repeat
@@ -145,8 +158,6 @@ Method name/Corresponding CSS element
  rightcol_bgcolor	/ background-color of right table cell  
  rightcol_ftcolor	/ font color of right table cell
 
-Remember that there are more methods (the info options listed above). 
-
 =head1 EXAMPLES
 
 Function-oriented style:
@@ -181,11 +192,39 @@ More examples . . .
 	# Ditto
 	$p->info_credits;
 
+=head1 no_links
+
+To remove all the default links and images, you can use the no_links method. 
+
+       $p->no_links;
+       $p->info_all; # contains no images or links. Good for printing!
+
+There are many links (mostly to module documentation) and a few images of camels in the default function. HTML::Perinfo will also detect if the client and server are the same machine and provide links to the local location of a module. This is useful if you want to see the local installation directory of a module in your browser. 
+
+More functions for altering the HTML in exciting ways will come in future versions.
+
+=head1 SECURITY
+
+Displaying detailed server information on the internet is not a good idea if security is a top concern, as it is for most system administrators, and HTML::Perlinfo reveals a lot of information about the local environment. While restricting what system users can publish online is wise, you can also hinder them from using the module by installing it outside of the usual module directories (see perldoc -q lib). Of course, preventing users from installing the module in their own home directories is another matter entirely. 
+
+=head1 REQUIREMENTS
+
+HTML::Perlinfo requires only 3 non-core modules. These 3 modules are:
+
+L<App::Info> (for some HTTPD information)
+
+L<Module::CoreList> (for Perl release dates)
+
+L<File::Which> (for searching the path)
+
 =head1 NOTES
 
-This is a work in progress. So expect to see big, exciting changes from version to version. 
+Some might notice that HTML::Perlinfo shares the look and feel of the PHP function phpinfo. It was originally inspired by that function and was first in the PHP namespace as PHP::Perlinfo, which is no longer available on CPAN.   
 
-Some might notice that HTML::Perlinfo shares the look and feel of the PHP function phpinfo. It was originally based on that function and was first in the PHP namespace as PHP::Perlinfo, which will no longer be available on CPAN.   
+=head1 RELEASE SCHEDULE
+
+Every month or so, there will be a new version. Version numbers will increase by 0.05 to reflect the large amount of changes
+ expected with each release. Emergency releases will bump the version by 0.01.
 
 =head1 BUGS
 
